Package: treeclimbR
Type: Package
Title: An algorithm to find optimal signal levels in a tree
Version: 1.9.0
Date: 2025-07-18
Authors@R: c(person("Ruizhu", "Huang", email = "ruizhuRH@gmail.com",
                    role = c("aut"), 
                    comment = c(ORCID = "0000-0003-3285-1945")),
             person("Charlotte", "Soneson", 
                    email = "charlottesoneson@gmail.com",
                    role = c("aut", "cre"), 
                    comment = c(ORCID = "0000-0003-3833-2169")))
Description: The arrangement of hypotheses in a hierarchical structure appears 
    in many research fields and often indicates different resolutions at which 
    data can be viewed. This raises the question of which resolution level 
    the signal should best be interpreted on. treeclimbR provides a flexible 
    method to select optimal resolution levels (potentially different levels 
    in different parts of the tree), rather than cutting the tree at an 
    arbitrary level. treeclimbR uses a tuning parameter to generate candidate 
    resolutions and from these selects the optimal one.
License: Artistic-2.0
Encoding: UTF-8
biocViews: StatisticalMethod, CellBasedAssays
Depends: R (>= 4.4.0)
Imports: TreeSummarizedExperiment (>= 1.99.0), edgeR, methods,
        SummarizedExperiment, S4Vectors, dirmult, dplyr, tibble, tidyr,
        ape, diffcyt, ggnewscale, ggplot2 (>= 3.4.0), viridis, ggtree,
        stats, utils, rlang
Suggests: knitr, rmarkdown, scales, testthat (>= 3.0.0), BiocStyle,
        GenomeInfoDb
RoxygenNote: 7.3.2
VignetteBuilder: knitr
URL: https://github.com/csoneson/treeclimbR
BugReports: https://github.com/csoneson/treeclimbR/issues
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/treeclimbR
git_branch: devel
git_last_commit: 90a98f4
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 23:43:23 UTC; biocbuild
Author: Ruizhu Huang [aut] (ORCID: <https://orcid.org/0000-0003-3285-1945>),
  Charlotte Soneson [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3833-2169>)
Maintainer: Charlotte Soneson <charlottesoneson@gmail.com>
Built: R 4.6.0; ; 2026-05-19 05:12:47 UTC; unix
