# Generated by roxygen2: do not edit by hand

export(TreeHeatmap)
export(aggDS)
export(buildTree)
export(calcMediansByTreeMarker)
export(calcTreeCounts)
export(calcTreeMedians)
export(edgerWrp)
export(evalCand)
export(fdr)
export(findChild)
export(findExcl)
export(getCand)
export(getData)
export(getLevel)
export(infoCand)
export(isConnect)
export(medianByClusterMarker)
export(nodeResult)
export(parEstimate)
export(runDA)
export(runDS)
export(selNode)
export(simData)
export(topNodes)
export(tpr)
export(treeScore)
importFrom(S4Vectors,metadata)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assayNames)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(TreeSummarizedExperiment,TreeSummarizedExperiment)
importFrom(TreeSummarizedExperiment,addLabel)
importFrom(TreeSummarizedExperiment,aggTSE)
importFrom(TreeSummarizedExperiment,colLinks)
importFrom(TreeSummarizedExperiment,colTree)
importFrom(TreeSummarizedExperiment,convertNode)
importFrom(TreeSummarizedExperiment,findDescendant)
importFrom(TreeSummarizedExperiment,isLeaf)
importFrom(TreeSummarizedExperiment,joinNode)
importFrom(TreeSummarizedExperiment,matTree)
importFrom(TreeSummarizedExperiment,printNode)
importFrom(TreeSummarizedExperiment,rowLinks)
importFrom(TreeSummarizedExperiment,rowTree)
importFrom(TreeSummarizedExperiment,showNode)
importFrom(ape,as.phylo)
importFrom(diffcyt,calcCounts)
importFrom(diffcyt,calcMediansByClusterMarker)
importFrom(dirmult,dirmult)
importFrom(dirmult,rdirichlet)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize_all)
importFrom(edgeR,DGEList)
importFrom(edgeR,calcNormFactors)
importFrom(edgeR,estimateDisp)
importFrom(edgeR,filterByExpr)
importFrom(edgeR,glmFit)
importFrom(edgeR,glmLRT)
importFrom(edgeR,glmQLFTest)
importFrom(edgeR,glmQLFit)
importFrom(edgeR,topTags)
importFrom(ggnewscale,new_scale_color)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_viridis_c)
importFrom(ggplot2,scale_fill_viridis_d)
importFrom(ggplot2,theme_void)
importFrom(ggtree,ggtree)
importFrom(methods,is)
importFrom(rlang,.data)
importFrom(stats,as.formula)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,p.adjust)
importFrom(stats,rmultinom)
importFrom(stats,rnbinom)
importFrom(stats,runif)
importFrom(tibble,column_to_rownames)
importFrom(tidyr,pivot_longer)
importFrom(utils,flush.console)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(viridis,viridis)
